﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.TravelingSalesman {

  /// <summary>
  /// A class for storing details of population diversity analysis results.
  /// </summary>
  [Item("TSPPopulationDiversityAnalysisDetails", "A class for storing details of population diversity analysis results.")]
  [StorableClass]
  public class TSPPopulationDiversityAnalysisDetails : NamedItem {

    [Storable]
    private ItemList<DoubleValue> averageSimilarities;
    public ItemList<DoubleValue> AverageSimilarities {
      get { return averageSimilarities; }
    }
    [Storable]
    private ItemList<DoubleValue> averageMaximumSimilarities;
    public ItemList<DoubleValue> AverageMaximumSimilarities {
      get { return averageMaximumSimilarities; }
    }

    [Storable]
    private ItemList<DoubleMatrix> similarities;
    public ItemList<DoubleMatrix> Similarities {
      get { return similarities; }
    }
    [Storable]
    private ItemList<DoubleArray> maximumSimilarities;
    public ItemList<DoubleArray> MaximumSimilarities {
      get { return maximumSimilarities; }
    }

    public TSPPopulationDiversityAnalysisDetails()
        : base() {
      averageSimilarities = new ItemList<DoubleValue>();
      averageMaximumSimilarities = new ItemList<DoubleValue>();
      similarities = new ItemList<DoubleMatrix>();
      maximumSimilarities = new ItemList<DoubleArray>();
    }

  }

}
